mchammer.Bond
=============

.. currentmodule:: mchammer

.. autoclass:: Bond
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Bond.get_atom1_id
      ~Bond.get_atom2_id
      ~Bond.get_id
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Bond.id
      ~Bond.atom_ids
   
   